@@ -1,6 +1,6 @@
 """Compatibility code for using CherryPy with various versions of Python.
 
-CherryPy 3.2 is compatible with Python versions 2.3+. This module provides a
+CherryPy 3.2 is compatible with Python versions 2.6+. This module provides a
 useful abstraction over the differences between Python versions, sometimes by
 preferring a newer idiom, sometimes an older one, and sometimes a custom one.
 
@@ -23,8 +23,6 @@ import threading
 import six
 
 if six.PY3:
-    basestring = (bytes, str)
-
     def ntob(n, encoding='ISO-8859-1'):
         """Return the given native string as a byte string in the given
         encoding.
@@ -49,8 +47,6 @@ if six.PY3:
         return n
 else:
     # Python 2
-    basestring = basestring
-
     def ntob(n, encoding='ISO-8859-1'):
         """Return the given native string as a byte string in the given
         encoding.
@@ -140,16 +136,16 @@ try:
     from urllib.request import parse_http_list, parse_keqv_list
 except ImportError:
     # Python 2
-    from urlparse import urljoin
-    from urllib import urlencode, urlopen
-    from urllib import quote, quote_plus
-    from urllib import unquote
-    from urllib2 import parse_http_list, parse_keqv_list
+    from urlparse import urljoin  # noqa
+    from urllib import urlencode, urlopen  # noqa
+    from urllib import quote, quote_plus  # noqa
+    from urllib import unquote  # noqa
+    from urllib2 import parse_http_list, parse_keqv_list  # noqa
 
 try:
     from threading import local as threadlocal
 except ImportError:
-    from cherrypy._cpthreadinglocal import local as threadlocal
+    from cherrypy._cpthreadinglocal import local as threadlocal  # noqa
 
 try:
     dict.iteritems
@@ -186,7 +182,7 @@ try:
     import builtins
 except ImportError:
     # Python 2
-    import __builtin__ as builtins
+    import __builtin__ as builtins  # noqa
 
 try:
     # Python 2. We try Python 2 first clients on Python 2
@@ -197,10 +193,10 @@ try:
     from BaseHTTPServer import BaseHTTPRequestHandler
 except ImportError:
     # Python 3
-    from http.cookies import SimpleCookie, CookieError
-    from http.client import BadStatusLine, HTTPConnection, IncompleteRead
-    from http.client import NotConnected
-    from http.server import BaseHTTPRequestHandler
+    from http.cookies import SimpleCookie, CookieError  # noqa
+    from http.client import BadStatusLine, HTTPConnection, IncompleteRead  # noqa
+    from http.client import NotConnected  # noqa
+    from http.server import BaseHTTPRequestHandler  # noqa
 
 # Some platforms don't expose HTTPSConnection, so handle it separately
 if six.PY3:
@@ -237,14 +233,6 @@ else:
     def set_daemon(t, val):
         t.setDaemon(val)
 
-try:
-    from email.utils import formatdate
-
-    def HTTPDate(timeval=None):
-        return formatdate(timeval, usegmt=True)
-except ImportError:
-    from rfc822 import formatdate as HTTPDate
-
 try:
     # Python 3
     from urllib.parse import unquote as parse_unquote
@@ -291,13 +279,14 @@ finally:
     else:
         json_encode = _json_encode
 
+text_or_bytes = six.text_type, six.binary_type
 
 try:
     import cPickle as pickle
 except ImportError:
     # In Python 2, pickle is a Python version.
     # In Python 3, pickle is the sped-up C version.
-    import pickle
+    import pickle  # noqa
 
 import binascii
 
@@ -307,7 +296,7 @@ def random20():
 try:
     from _thread import get_ident as get_thread_ident
 except ImportError:
-    from thread import get_ident as get_thread_ident
+    from thread import get_ident as get_thread_ident  # noqa
 
 try:
     # Python 3
