@@ -7,7 +7,7 @@ from hashlib import md5
 import six
 
 import cherrypy
-from cherrypy._cpcompat import basestring
+from cherrypy._cpcompat import text_or_bytes
 from cherrypy.lib import httputil as _httputil
 from cherrypy.lib import is_iterator
 
@@ -533,7 +533,7 @@ def accept(media=None, debug=False):
     """
     if not media:
         return
-    if isinstance(media, basestring):
+    if isinstance(media, text_or_bytes):
         media = [media]
     request = cherrypy.serving.request
 
@@ -630,3 +630,19 @@ def autovary(ignore=None, debug=False):
         v.sort()
         resp_h['Vary'] = ', '.join(v)
     request.hooks.attach('before_finalize', set_response_header, 95)
+
+
+def convert_params(exception=ValueError, error=400):
+    """Convert request params based on function annotations, with error handling.
+
+    exception
+        Exception class to catch.
+
+    status
+        The HTTP error code to return to the client on failure.
+    """
+    request = cherrypy.serving.request
+    types = request.handler.callable.__annotations__
+    with cherrypy.HTTPError.handle(exception, error):
+        for key in set(types).intersection(request.params):
+            request.params[key] = types[key](request.params[key])
