@@ -4,6 +4,7 @@ from cherrypy.test import helper
 
 class WSGI_VirtualHost_Test(helper.CPWebCase):
 
+    @staticmethod
     def setup_server():
 
         class ClassOfRoot(object):
@@ -11,9 +12,9 @@ class WSGI_VirtualHost_Test(helper.CPWebCase):
             def __init__(self, name):
                 self.name = name
 
+            @cherrypy.expose
             def index(self):
                 return "Welcome to the %s website!" % self.name
-            index.exposed = True
 
         default = cherrypy.Application(None)
 
@@ -23,7 +24,6 @@ class WSGI_VirtualHost_Test(helper.CPWebCase):
             domains['www.classof%s.example' % year] = app
 
         cherrypy.tree.graft(cherrypy._cpwsgi.VirtualHost(default, domains))
-    setup_server = staticmethod(setup_server)
 
     def test_welcome(self):
         if not cherrypy.server.using_wsgi:
